
// MiniCasino class for CS 171 Project 1 (do not update)
// Author:  John Paul Vergara

#include <string>
#include <sstream>
#include "MiniCasino.h"
using namespace std;

MiniCasino::MiniCasino( double expA, double expB, unsigned seed )
{
	C = 10000;
	numGames = 10000;
	srand( seed );
	expAGiven = expA;
	expBGiven = expB;
	// negative expected payoff means "unknown"
	// in this case, expected payoff is randonly generated
	if ( expA < 0 || expB < 0 )
	{
		if ( expA < 0 )
		{
			expA = 0.6 + randDouble();
		}
		if ( expB < 0 )
		{
			expB = 0.6 + randDouble();
		}			
	}
	// make the seeds for the slot machines dependent on the seed parameter
	A = new SlotMachine( expA );
	B = new SlotMachine( expB );
}

void MiniCasino::setEnv( int C, int M )
{
	this->C = C;
	this->numGames = M*6;
}

int MiniCasino::getBal()
{
	return C;
}

string MiniCasino::play( string decision )
{
	ostringstream oss;
	
	numGames--;
	int awin = 0, bwin = 0;
	if ( decision == "NO" )
	{
		return "";
	}
	else if ( decision == "A" )
	{
		if ( C < 1 || numGames < 0 )
		{
			return "0";
		}
		awin = A->play();
		C += -1 + awin;
		
		oss << awin;
		return oss.str();
	}
	else if ( decision == "B" )
	{
		if ( C < 1 || numGames < 0 )
		{
			return "0";
		}
		bwin = B->play();
		C += -1 + bwin;
		
		oss << bwin;
		return oss.str();
	}
	else if ( decision == "AB" )
	{
		if ( C < 2 || numGames < 0 )
		{
			return "0 0";
		}
		awin = A->play();
		bwin = B->play();
		C += -2 + awin + bwin;
		oss << awin << " " << bwin;
		return oss.str();
	}
	else
	{
		return "ERROR";
	}
}

double MiniCasino::getexpA()
{
	return expAGiven;
}

double MiniCasino::getexpB()
{
	return expBGiven;
}

SlotMachine::SlotMachine( double exp )
{
	zero = 0.60;
	one = 0.95;
	
	// exp = 0.6 x 0 + 0.35 x 1 + f x 5 + (0.05-f) x 100
	// f = (5.35-exp)/95
	
	double f = ( 5.35 - exp )/95;
	five = 0.95 + f;
	
}

int SlotMachine::play()
{
	double randomNum = randDouble();
	if ( randomNum < zero )
	{
		return 0;
	}
	else if ( randomNum < one )
	{
		return 1;
	}
	else if ( randomNum < five )
	{
		return 5;
	}
	else
	{
		return 100;
	}
}

double randDouble()
{
	// returns a random number between 0 and 1.0
	return 1.0*rand()/RAND_MAX;
}
